# Generated by Django 4.0.7 on 2023-05-31 17:01

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("miningtaxes", "0008_character_monthly_credits_json_and_more"),
    ]

    operations = [
        migrations.CreateModel(
            name="Stats",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("admin_char_json", models.JSONField(default=None, null=True)),
                ("admin_main_json", models.JSONField(default=None, null=True)),
                ("ore_prices_json", models.JSONField(default=None, null=True)),
                ("admin_mining_by_sys_json", models.JSONField(default=None, null=True)),
                ("admin_tax_revenue_json", models.JSONField(default=None, null=True)),
                ("admin_month_json", models.JSONField(default=None, null=True)),
                ("admin_corp_ledger", models.JSONField(default=None, null=True)),
                (
                    "admin_corp_mining_history",
                    models.JSONField(default=None, null=True),
                ),
                ("leaderboards", models.JSONField(default=None, null=True)),
            ],
        ),
    ]
