# Generated by Django 4.2.11 on 2024-06-14 00:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("miningtaxes", "0012_stats_user_mining_ledger_90day"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="settings",
            name="tax_Gasses",
        ),
        migrations.RemoveField(
            model_name="settings",
            name="tax_Ice",
        ),
        migrations.RemoveField(
            model_name="settings",
            name="tax_Mercoxit",
        ),
        migrations.RemoveField(
            model_name="settings",
            name="tax_Ores",
        ),
        migrations.RemoveField(
            model_name="settings",
            name="tax_R16",
        ),
        migrations.RemoveField(
            model_name="settings",
            name="tax_R32",
        ),
        migrations.RemoveField(
            model_name="settings",
            name="tax_R4",
        ),
        migrations.RemoveField(
            model_name="settings",
            name="tax_R64",
        ),
        migrations.RemoveField(
            model_name="settings",
            name="tax_R8",
        ),
        migrations.AddField(
            model_name="oreprices",
            name="tax_rate",
            field=models.FloatField(default=10.0),
        ),
    ]
